package com.benyun.project.third.TransferDirect.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.benyun.project.third.TransferDirect.mapper.KingdeeTransferDirectMapper;
import com.benyun.project.third.TransferDirect.domain.KingdeeTransferDirect;
import com.benyun.project.third.TransferDirect.service.IKingdeeTransferDirectService;
import com.benyun.common.utils.text.Convert;

/**
 * 金蝶直接调拨单Service业务层处理
 *
 * @author benyun
 * @date 2024-01-04
 */
@Service
public class KingdeeTransferDirectServiceImpl implements IKingdeeTransferDirectService
{
    @Autowired
    private KingdeeTransferDirectMapper kingdeeTransferDirectMapper;

    /**
     * 查询金蝶直接调拨单
     *
     * @param id 金蝶直接调拨单主键
     * @return 金蝶直接调拨单
     */
    @Override
    public KingdeeTransferDirect selectKingdeeTransferDirectById(Long id)
    {
        return kingdeeTransferDirectMapper.selectKingdeeTransferDirectById(id);
    }

    /**
     * 查询金蝶直接调拨单列表
     *
     * @param kingdeeTransferDirect 金蝶直接调拨单
     * @return 金蝶直接调拨单
     */
    @Override
    public List<KingdeeTransferDirect> selectKingdeeTransferDirectList(KingdeeTransferDirect kingdeeTransferDirect)
    {
        return kingdeeTransferDirectMapper.selectKingdeeTransferDirectList(kingdeeTransferDirect);
    }

    /**
     * 新增金蝶直接调拨单
     *
     * @param kingdeeTransferDirect 金蝶直接调拨单
     * @return 结果
     */
    @Override
    public int insertKingdeeTransferDirect(KingdeeTransferDirect kingdeeTransferDirect)
    {
        return kingdeeTransferDirectMapper.insertKingdeeTransferDirect(kingdeeTransferDirect);
    }

    /**
     * 修改金蝶直接调拨单
     *
     * @param kingdeeTransferDirect 金蝶直接调拨单
     * @return 结果
     */
    @Override
    public int updateKingdeeTransferDirect(KingdeeTransferDirect kingdeeTransferDirect)
    {
        return kingdeeTransferDirectMapper.updateKingdeeTransferDirect(kingdeeTransferDirect);
    }

    /**
     * 批量删除金蝶直接调拨单
     *
     * @param ids 需要删除的金蝶直接调拨单主键
     * @return 结果
     */
    @Override
    public int deleteKingdeeTransferDirectByIds(String ids)
    {
        return kingdeeTransferDirectMapper.deleteKingdeeTransferDirectByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除金蝶直接调拨单信息
     *
     * @param id 金蝶直接调拨单主键
     * @return 结果
     */
    @Override
    public int deleteKingdeeTransferDirectById(Long id)
    {
        return kingdeeTransferDirectMapper.deleteKingdeeTransferDirectById(id);
    }
}
